@@ -1,15 +1,32 @@
+"""
+Creator module.
+
+This module provides the following classes:
+
+- Creator
+- CreatorSchema
+"""
 from marshmallow import EXCLUDE, Schema, fields, post_load, pre_load
 
 from Simyan.generic_entries import GenericEntrySchema, ImageEntrySchema
 
 
 class Creator:
+    """
+    The Creator object contains information for creators.
+
+    :param `**kwargs`: The keyword arguments is used for setting creator data from Comic Vine.
+    """
+
     def __init__(self, **kwargs):
+        """Intialize a new Creator."""
         for k, v in kwargs.items():
             setattr(self, k, v)
 
 
 class CreatorSchema(Schema):
+    """Schema for the Creator API."""
+
     aliases = fields.Str(allow_none=True)
     api_url = fields.Url(data_key="api_detail_url")
     country = fields.Str()
@@ -34,11 +51,21 @@ class CreatorSchema(Schema):
     website = fields.Str(allow_none=True)
 
     class Meta:
+        """Any unknown fields will be excluded."""
+
         unknown = EXCLUDE
         dateformat = "%Y-%m-%d %H:%M:%S"
+        datetimeformat = "%Y-%m-%d %H:%M:%S"
 
     @pre_load
     def process_input(self, data, **kwargs):
+        """
+        Only keep the date of death information from Comic Vine.
+
+        The time zone info they include is not of any use.
+
+        :param data: Data from the Comic Vine response
+        """
         new_data = data
 
         if "death" in new_data and new_data["death"] is not None:
@@ -48,4 +75,12 @@ class CreatorSchema(Schema):
 
     @post_load
     def make_object(self, data, **kwargs) -> Creator:
+        """
+        Make the Creator object.
+
+        :param data: Data from Comic Vine reponse.
+
+        :returns: :class:`Creator` object
+        :rtype: Creator
+        """
         return Creator(**data)
