@@ -1,3 +1,12 @@
+"""
+PublishersList module.
+
+This module provides the following classes:
+
+- PublisherResult
+- PublisherResultSchema
+- PublishersList
+"""
 from marshmallow import EXCLUDE, Schema, ValidationError, fields, post_load
 
 from Simyan.exceptions import APIError
@@ -5,12 +14,21 @@ from Simyan.generic_entries import ImageEntrySchema
 
 
 class PublisherResult:
+    """
+    The PublisherResult object contains information for a publisher.
+
+    :param `**kwargs`: The keyword arguments is used for setting publisher data from Comic Vine.
+    """
+
     def __init__(self, **kwargs):
+        """Intialize a new PublisherResult."""
         for k, v in kwargs.items():
             setattr(self, k, v)
 
 
 class PublisherResultSchema(Schema):
+    """Schema for the PublisherResult API."""
+
     aliases = fields.Str(allow_none=True)
     api_url = fields.Url(data_key="api_detail_url")
     date_added = fields.DateTime()
@@ -26,16 +44,30 @@ class PublisherResultSchema(Schema):
     summary = fields.Str(data_key="deck", allow_none=True)
 
     class Meta:
+        """Any unknown fields will be excluded."""
+
         unknown = EXCLUDE
-        dateformat = "%Y-%m-%d %H:%M:%S"
+        dateformat = "%Y-%m-%d"
+        datetimeformat = "%Y-%m-%d %H:%M:%S"
 
     @post_load
     def make_object(self, data, **kwargs) -> PublisherResult:
+        """
+        Make the PublisherResult object.
+
+        :param data: Data from the Comic Vine response.
+
+        :returns: :class:`PublisherResult` object
+        :rtype: PublisherResult
+        """
         return PublisherResult(**data)
 
 
 class PublisherList:
+    """The PublishersList object contains a list of `PublisherResult` objects."""
+
     def __init__(self, response):
+        """Initialize a new PublishersList."""
         self.publishers = []
 
         schema = PublisherResultSchema()
@@ -48,10 +80,13 @@ class PublisherList:
             self.publishers.append(result)
 
     def __iter__(self):
+        """Return an iterator object."""
         return iter(self.publishers)
 
     def __len__(self):
+        """Return the length of the object."""
         return len(self.publishers)
 
     def __getitem__(self, index: int):
+        """Return the object of a at index."""
         return self.publishers[index]
