@@ -1,5 +1,12 @@
-import pytest
+"""
+Test Creators module.
+
+This module contains tests for Creator objects.
+"""
 import datetime
+
+import pytest
+
 from Simyan.exceptions import APIError
 
 COUNTRY = "United States"
@@ -21,6 +28,7 @@ WEBSITE = None
 
 
 def test_creator(comicvine):
+    """Test for a known creator."""
     result = comicvine.creator(ID)
     assert result.country == COUNTRY
     assert result.date_of_birth == DATE_OF_BIRTH
@@ -41,16 +49,20 @@ def test_creator(comicvine):
 
 
 def test_creator_fail(comicvine):
+    """Test for a non-existant creator."""
     with pytest.raises(APIError):
         comicvine.creator(-1)
 
+
 def test_creator_with_dob(comicvine):
+    """Test creators date of birth & death."""
     kirby = comicvine.creator(5614)
     assert kirby.date_of_birth == datetime.date(1917, 8, 28)
     assert kirby.date_of_death == datetime.date(1994, 2, 6)
 
 
 def test_creator_list(comicvine):
+    """Test the CreatorsList."""
     search_results = comicvine.creator_list({"filter": f"name:{NAME}"})
     result = [x for x in search_results if x.id == ID][0]
     assert result.country == COUNTRY
@@ -66,5 +78,6 @@ def test_creator_list(comicvine):
 
 
 def test_creator_list_empty(comicvine):
+    """Test CreatorList with bad response."""
     results = comicvine.creator_list({"filter": "name:INVALID"})
     assert len(results) == 0
