@@ -1,3 +1,8 @@
+"""
+Test Story Arcs module.
+
+This module contains tests for Story Arc objects.
+"""
 import pytest
 
 from Simyan.exceptions import APIError
@@ -15,6 +20,7 @@ PUBLISHER_NAME = "DC Comics"
 
 
 def test_story_arc(comicvine):
+    """Test for known arcs."""
     result = comicvine.story_arc(ID)
     assert result.first_issue.id == FIRST_ISSUE_ID
     assert result.first_issue.name == FIRST_ISSUE_NAME
@@ -29,11 +35,13 @@ def test_story_arc(comicvine):
 
 
 def test_story_arc_fail(comicvine):
+    """Test for bad arc requests."""
     with pytest.raises(APIError):
         comicvine.story_arc(-1)
 
 
 def test_story_arc_list(comicvine):
+    """Test for StoryArcList."""
     search_results = comicvine.story_arc_list({"filter": f"name:{NAME}"})
     result = [x for x in search_results if x.id == ID][0]
     assert result.first_issue.id == FIRST_ISSUE_ID
@@ -47,5 +55,6 @@ def test_story_arc_list(comicvine):
 
 
 def test_story_arc_list_empty(comicvine):
+    """Test StoryArcList with no results."""
     results = comicvine.story_arc_list({"filter": "name:INVALID"})
     assert len(results) == 0
